import QtQuick 2.2
import FmNetwork 1.0
//import FmNetChecker 1.0
/*!
    \qmltype AppNetwork
    \since FmNetwork 1.0
    \inqmlmodule FmNetwork
    \brief 网络访问类

    包含http的get\\pos\\delete\\put\\上传文件\\下载文件
*/
Item{
    id: idANet
    // 网络改变事件
    signal netChanged()
    AppNetManager{id: fmNetmanager}
    // 网络状态检测
//    FmNetChecker{
//        id: __idChecker
//        onNetStateChanged: idANet.netChanged()
//    }

    Connections{
        target:NetChecker
        onNetStateChanged:{
            console.log("----------onNetStateChanged---------:",state);
            idANet.netChanged();
        }
    }
    /*!
       网络状态
         -1: 无网络
          0: 2G/3G/4G
          1: wifi
    */
    //property alias netState: __idChecker.netState
    property var netState: NetChecker.netState

    //手动关闭网络检测
    property var closeNetChecker: function(){
        NetChecker.closeNetChecker();
    }
    //用于关闭后手动打开网络检测
    property var openNetChecker: function(){
        NetChecker.openNetChecker();
    }

     // 编码
     property var encodeUrl:function(url){
        return fmNetmanager.encodeUrl(url);
     }

    /*!
       \qmlproperty int timeout
       超时时间设置
    */
    property alias timeout: fmNetmanager.timeout
    /*!
       清除cookies
    */
    property var clearCookies: function(){
        fmNetmanager.clearCookies();
    }
    /*! \internal
       网络响应的绑定
    */
    property var bindReplay: function(replay){
        replay.readObj = function(){
            try {
                return JSON.parse(replay.readAll());
            }
            catch (e){
                return {};
            }
        }

        return replay;
    }

    /*! \internal
       绑定回调函数
    */
    property var bind: function(rep, callback, callbackErr, callbackProgress){
        // 以下代码用于绑定用户函数，并在远行结束后解除绑定
        var replay = bindReplay(rep);
        // 用于解除绑定
        var disFun = function(){
            replay.error.disconnect(errFun);
            replay.progress.disconnect(progressFun);
            replay.finished.disconnect(finishedFun);
        }

        // 发生错误的回调函数
        var errFun = function(err, msg){

            // windows使用qt的错误码，并不是http的错误码，所以要转换一下
            var change=[];
            if ( Qt.platform.os == "windows" ){
                change.push({a:1,b:503});
                change.push({a:2,b:12031});
                change.push({a:3,b:404});
                change.push({a:4,b:408});
                change.push({a:5,b:12017});
                change.push({a:7,b:307});
                change.push({a:8,b:408});
                change.push({a:9,b:403});

                change.push({a:101,b:503});
                change.push({a:102,b:12031});
                change.push({a:103,b:12165});
                change.push({a:104,b:12002});
                change.push({a:105,b:407});

                change.push({a:201,b:401});
                change.push({a:202,b:403});//403或405
                change.push({a:203,b:404});
                change.push({a:204,b:401});
                change.push({a:205,b:12050});
                change.push({a:206,b:409});
                change.push({a:207,b:410});

                change.push({a:301,b:12008});
                change.push({a:302,b:400});//400或418
                change.push({a:399,b:12130});

                change.push({a:401,b:500});
                change.push({a:402,b:501});
                change.push({a:403,b:503});
            }


            for( var i=0; i<change.length; ++i ){
                if ( change[i].a == err ){
                    err = change[i].b;
                    break;
                }
            }

            if ( callbackErr instanceof Function )
                callbackErr(err, msg);
            console.log("("+err+")"+msg);
            disFun();

        }
        // 正常结束的回调函数
        var finishedFun = function(){
            if ( callback instanceof Function )
                callback(replay);
            disFun();
        }
        // 处理过程的回调函数
        var progressFun = function(pos, total){
            if ( callbackProgress instanceof Function )
                callbackProgress(replay, pos, total);
        }

        // 绑定
        replay.error.connect(errFun);
        replay.progress.connect(progressFun);
        replay.finished.connect(finishedFun);

        return replay;
    }

    /*! \internal
       合成json的头
    */
    property var onNewJsonReq: function(req, isGet){
        if ( !isGet )
            req.setHeader(0, "application/json");
        req.setRawHeader("version","1.0");
        req.setRawHeader("client-type",Qt.platform.os);
        req.setRawHeader("x-requested-with","XMLHttpRequest");
    }

    /*! \internal
       合成表单访问的头
    */
    property var onNewFileReq: function(req){
        req.setHeader(6, "multipart/form-data");
        req.setRawHeader("version","1.0");
        req.setRawHeader("client-type",Qt.platform.os);
        req.setRawHeader("x-requested-with","XMLHttpRequest");
    }

    /*! \internal
       新建网络访问头
    */
    property var newReq: function(url, isFile, isGet){
        var req = fmNetmanager.req();
        if ( typeof(url) == "string" )
            req.url = url;

        if ( isFile == true ){
            if ( onNewFileReq instanceof Function )
                onNewFileReq(req);
        }
        else if ( onNewJsonReq instanceof Function )
            onNewJsonReq(req, isGet);

        console.log(url);

        return req;
    }

    /*! \internal
       网址或请求的头转成请求的头对象
    */
    property var toReq: function(req, isFile, isGet){
        if ( typeof(req) == "string" )
            return newReq(req, isFile, isGet);
        return req;
    }
    function __accessx(url, method, data, headers, callback, callbackErr, callbackProgress){
        var doc = new XMLHttpRequest;
        doc.open(method, url, true);
        //console.log("method"+method+"url::"+url);
        if ( data ){
            if ( typeof(data)!="string" )
                data = JSON.stringify(data);
            if ( !headers )
                headers = {};
            headers["Content-length"] = data.length;
        }

        if ( headers ){
            for( var a in headers ){
                doc.setRequestHeader(a, headers[a]);
            }
        }
        doc.onreadystatechange = function() {
            if (doc.readyState === XMLHttpRequest.DONE ) {
                if ( doc.status === 200){
                    if ( !(callback instanceof Function) )
                        return;
                    var v = {}
                    v.readAll = function(){
                        return doc.responseText;
                    }
                    v.readObj = function(){
                        try{
                            return JSON.parse(doc.responseText);
                        }
                        catch(e){
                            return null;
                        }
                    }
                    callback(v)
                }
                else if ( callbackErr instanceof Function ){
                    //console.log(doc.status+"--"+doc.responseText)
                    callbackErr(doc.status, doc.responseText);
                }
            }
        }
        if ( data ){
            doc.send(data);
        }
        else
            doc.send();
    }

    /*!
        \qmlmethod get
        \list
            \li function get(req, callback, callbackErr, callbackProgress)
            \li 说明：get方式访问网络资源
            \li 参数：
            \list
                \li req 访问网址或访问头对象，一般为网址
                \li callback(replay) 成功读取文件的回调，replay:响应类,有readAll(),readObj()两个方法
                \li callbackError(err,msg) 发生错误时的回调，可以不传，err:错误编码，msg:错误内容
                \li callbackProgress(replay, pos, total) 过程回调，可以不传，replay:响应类,有readAll(),readObj()两个方法,pos:接收到的字节数，total:总字节数
            \endlist
            \li 返回：replay 响应类对象
            \li 用法示例：
            \code
                import FmNetwork 1.0
                ...
                AppNetwork{
                    id:idNet
                    Component.onCompleted: {
                        idNet.get("http://www.baidu.com/",function(dat){
                            // 打印返回值
                            console.log(dat);
                        },
                        function(err, msg){
                            // 发现错误
                            console.log("("+err+")"+msg);
                        },
                        function(replay, pos, total){
                            // 过程回调
                            console.log(pos+"/"+total);
                        });
                    }
                }
            \endcode
         \endlist
         \sa post
         \sa put
         \sa deleteResource
         \sa downFile
         \sa upLoadFileMultipart
         \sa upLoadFileMultiparts
    */
    property var get: function(req, callback, callbackErr, callbackProgress){
        // 直接请求
        //__accessx(req, "GET", null, null, callback, callbackErr, callbackProgress);
        var rep = fmNetmanager.get(toReq(req, false, true));
        return bind(rep, callback, callbackErr, callbackProgress);
    }

    /*!
        \qmlmethod post
        \list
            \li function post(req, dat, callback, callbackErr, callbackProgress)
            \li 说明：post方式访问网络资源
            \li 参数：
            \list
                \li req 访问网址或访问头对象，一般为网址
                \li dat 发送的数据
                \li callback(replay) 成功读取文件的回调，replay:响应类,有readAll(),readObj()两个方法
                \li callbackError(err,msg) 发生错误时的回调，可以不传，err:错误编码，msg:错误内容
                \li callbackProgress(replay, pos, total) 过程回调，可以不传，replay:响应类,有readAll(),readObj()两个方法,pos:接收到的字节数，total:总字节数
            \endlist
            \li 返回：replay 响应类对象
            \li 用法示例：
            \code
                import FmNetwork 1.0
                ...
                AppNetwork{
                    id:idNet
                    Component.onCompleted: {
                        idNet.post("http://www.baidu.com/","你好",function(dat){
                            // 打印返回值
                            console.log(dat);
                        },
                        function(err, msg){
                            // 发现错误
                            console.log("("+err+")"+msg);
                        },
                        function(replay, pos, total){
                            // 过程回调
                            console.log(pos+"/"+total);
                        });
                    }
                }
            \endcode
         \endlist
         \sa get
         \sa put
         \sa deleteResource
         \sa downFile
         \sa upLoadFileMultipart
         \sa upLoadFileMultiparts
    */
    property var post: function(req, dat, callback, callbackErr, callbackProgress){
        // 直接请求
        var headers = {
            "Content-Type":"application/json",
            "version":"1.0",
            "x-requested-with":"XMLHttpRequest",
            "client-type":Qt.platform.os
        }

        //__accessx(req, "POST", dat, headers, callback, callbackErr, callbackProgress);
        if ( typeof(dat) != "string" )
            dat = JSON.stringify(dat);
        console.log(dat);
        var rep = fmNetmanager.post(toReq(req), dat);
        return bind(rep, callback, callbackErr, callbackProgress);
    }
    /*!
        \qmlmethod put
        \list
            \li function put(req, dat, callback, callbackErr, callbackProgress)
            \li 说明：put方式访问网络资源
            \li 参数：
            \list
                \li req 访问网址或访问头对象，一般为网址
                \li dat 发送的数据
                \li callback(replay) 成功读取文件的回调，replay:响应类,有readAll(),readObj()两个方法
                \li callbackError(err,msg) 发生错误时的回调，可以不传，err:错误编码，msg:错误内容
                \li callbackProgress(replay, pos, total) 过程回调，可以不传，replay:响应类,有readAll(),readObj()两个方法,pos:接收到的字节数，total:总字节数
            \endlist
            \li 返回：replay 响应类对象
            \li 用法示例：
            \code
                import FmNetwork 1.0
                ...
                AppNetwork{
                    id:idNet
                    Component.onCompleted: {
                        idNet.put("http://www.baidu.com/","更新数据",function(dat){
                            // 打印返回值
                            console.log(dat);
                        },
                        function(err, msg){
                            // 发现错误
                            console.log("("+err+")"+msg);
                        },
                        function(replay, pos, total){
                            // 过程回调
                            console.log(pos+"/"+total);
                        });
                    }
                }
            \endcode
         \endlist
         \sa get
         \sa post
         \sa deleteResource
         \sa downFile
         \sa upLoadFileMultipart
         \sa upLoadFileMultiparts
    */
    property var put: function(req, dat, callback, callbackErr, callbackProgress){
        // 直接请求
//        var headers = {
//            "Content-Type":"application/json",
//            "version":"1.0",
//            "x-requested-with":"XMLHttpRequest",
//            "client-type":Qt.platform.os
//        }

        //__accessx(req, "PUT", dat, headers, callback, callbackErr, callbackProgress);
        if ( typeof(dat) != "string" )
            dat = JSON.stringify(dat);
        console.log(dat);
        var rep = fmNetmanager.put(toReq(req), dat);
        return bind(rep, callback, callbackErr, callbackProgress);
    }

    /*!
        \qmlmethod deleteResource
        \list
            \li function deleteResource(req, dat, callback, callbackErr, callbackProgress)
            \li 说明：delete方式访问网络资源
            \li 参数：
            \list
                \li req 访问网址或访问头对象，一般为网址
                \li callback(replay) 成功读取文件的回调，replay:响应类,有readAll(),readObj()两个方法
                \li callbackError(err,msg) 发生错误时的回调，可以不传，err:错误编码，msg:错误内容
                \li callbackProgress(replay, pos, total) 过程回调，可以不传，replay:响应类,有readAll(),readObj()两个方法,pos:接收到的字节数，total:总字节数
            \endlist
            \li 返回：replay 响应类对象
            \li 用法示例：
            \code
                import FmNetwork 1.0
                ...
                AppNetwork{
                    id:idNet
                    Component.onCompleted: {
                        idNet.deleteResource("http://www.baidu.com/",function(dat){
                            // 打印返回值
                            console.log(dat);
                        },
                        function(err, msg){
                            // 发现错误
                            console.log("("+err+")"+msg);
                        },
                        function(replay, pos, total){
                            // 过程回调
                            console.log(pos+"/"+total);
                        });
                    }
                }
            \endcode
         \endlist
         \sa get
         \sa post
         \sa put
         \sa downFile
         \sa upLoadFileMultipart
         \sa upLoadFileMultiparts
    */
    property var deleteResource: function(req, callback, callbackErr, callbackProgress){
        // 直接请求
        //__accessx(req, "DELETE", null, null, callback, callbackErr, callbackProgress);

        var rep = fmNetmanager.deleteResource(toReq(req, false, true));
        return bind(rep, callback, callbackErr, callbackProgress);
    }

    /*!
        \qmlmethod downFile
        \list
            \li function downFile(req, path, callback, callbackErr, callbackProgress)
            \li 说明：下载文件
            \li 参数：
            \list
                \li req 访问网址或访问头对象，一般为网址
                \li path 下载的文件，保存的路径
                \li callback(replay) 成功读取文件的回调，replay:响应类,有readAll(),readObj()两个方法
                \li callbackError(err,msg) 发生错误时的回调，可以不传，err:错误编码，msg:错误内容
                \li callbackProgress(replay, pos, total) 过程回调，可以不传，replay:响应类,有readAll(),readObj()两个方法,pos:接收到的字节数，total:总字节数
            \endlist
            \li 返回：replay 响应类对象
            \li 用法示例：
            \code
                import FmNetwork 1.0
                ...
                AppNetwork{
                    id:idNet
                    Component.onCompleted: {
                        idNet.downFile("http://www.baidu.com/","file:///d:/a.txt",function(dat){
                            // 打印返回值
                            console.log(dat);
                        },
                        function(err, msg){
                            // 发现错误
                            console.log("("+err+")"+msg);
                        },
                        function(replay, pos, total){
                            // 过程回调
                            console.log(pos+"/"+total);
                        });
                    }
                }
            \endcode
         \endlist
         \sa get
         \sa post
         \sa put
         \sa deleteResource
         \sa upLoadFileMultipart
         \sa upLoadFileMultiparts
    */
    property var downFile: function(req, path, callback, callbackErr, callbackProgress){
        // 直接请求
        var rep = fmNetmanager.downLoadFile(toReq(req, false, true), path);
        return bind(rep, callback, callbackErr, callbackProgress);
    }


    function updaloads(req, path, callback, callbackErr, callbackProgress,index, userType){
        upLoadFileMultipart(req,path[index],function(rep){
            if(index+1 < path.length)
                updaloads(req,path,callback, callbackErr, callbackProgress,index+1, userType);
            else{
                if(callback instanceof Function)
                    callback(rep);
            }
        },function(err,msg){
            if(callbackErr instanceof Function)
                callbackErr(err,msg);
        },callbackProgress, userType);
    }

    /*!
        \qmlmethod upLoadFileMultipart
        \list
            \li function upLoadFileMultipart(req, path, callback, callbackErr, callbackProgress)
            \li 说明：上传文件，采用表单方式
            \li 参数：
            \list
                \li req 访问网址或访问头对象，一般为网址
                \li path 要上传的文件路径
                \li callback(replay) 成功读取文件的回调，replay:响应类,有readAll(),readObj()两个方法
                \li callbackError(err,msg) 发生错误时的回调，可以不传，err:错误编码，msg:错误内容
                \li callbackProgress(replay, pos, total) 过程回调，可以不传，replay:响应类,有readAll(),readObj()两个方法,pos:接收到的字节数，total:总字节数
            \endlist
            \li 返回：replay 响应类对象
            \li 用法示例：
            \code
                import FmNetwork 1.0
                ...
                AppNetwork{
                    id:idNet
                    Component.onCompleted: {
                        idNet.upLoadFileMultipart("http://www.baidu.com/","file:///d:/a.txt",function(dat){
                            // 打印返回值
                            console.log(dat);
                        },
                        function(err, msg){
                            // 发现错误
                            console.log("("+err+")"+msg);
                        },
                        function(replay, pos, total){
                            // 过程回调
                            console.log(pos+"/"+total);
                        });
                    }
                }
            \endcode
         \endlist
         \sa get
         \sa post
         \sa put
         \sa downFile
         \sa deleteResource
         \sa upLoadFileMultiparts
    */
    property var upLoadFileMultipart: function(req, path, callback, callbackErr, callbackProgress, userType){
        // 直接请求
        var ty = types;
        if ( userType !== undefined ){
            ty = JSON.parse(JSON.stringify(types));
            for( var a in userType ){
                ty[a] = userType[a];
            }
        }

        var rep = fmNetmanager.upLoadFileMultipart(toReq(req, true), path,ty);
        return bind(rep, callback, callbackErr, callbackProgress);
    }

    /*!
        \qmlmethod upLoadFileMultiparts
        \list
            \li function upLoadFileMultiparts(req, paths, callback, callbackErr, callbackProgress)
            \li 说明：上传多个文件，采用表单方式
            \li 参数：
            \list
                \li req 访问网址或访问头对象，一般为网址
                \li paths 要上传的文件路径,多个
                \li callback(replay) 成功读取文件的回调，replay:响应类,有readAll(),readObj()两个方法
                \li callbackError(err,msg) 发生错误时的回调，可以不传，err:错误编码，msg:错误内容
                \li callbackProgress(replay, pos, total) 过程回调，可以不传，replay:响应类,有readAll(),readObj()两个方法,pos:接收到的字节数，total:总字节数
            \endlist
            \li 返回：replay 响应类对象
            \li 用法示例：
            \code
                import FmNetwork 1.0
                ...
                AppNetwork{
                    id:idNet
                    Component.onCompleted: {
                        var files = ["file:///d:/a.txt","file:///d:/b.txt","file:///d:/c.txt"]
                        idNet.upLoadFileMultiparts("http://www.baidu.com/",files,function(dat){
                            // 打印返回值
                            console.log(dat);
                        },
                        function(err, msg){
                            // 发现错误
                            console.log("("+err+")"+msg);
                        },
                        function(replay, pos, total){
                            // 过程回调
                            console.log(pos+"/"+total);
                        });
                    }
                }
            \endcode
         \endlist
         \sa get
         \sa post
         \sa put
         \sa deleteResource
         \sa downFile
         \sa upLoadFileMultipart
    */
    property var upLoadFileMultiparts: function(req, paths, callback, callbackErr, callbackProgress, userType){

            updaloads(req, paths, callback, callbackErr, callbackProgress,0, userType);
//        // 直接请求
//        var rep = fmNetmanager.upLoadFileMultiparts(toReq(req, true), paths);
//        return bind(rep, callback, callbackErr, callbackProgress);
    }

    /*!
       \qmlproperty var types
       后缀名与类型绑定关系
    */
    property var types: {
         "ez":"application/andrew-inset",
         "hqx":"application/mac-binhex40",
         "cpt":"application/mac-compactpro",
         "doc":"application/msword",
         "docx":"application/msword",
         "bin":"application/octet-stream",
         "dms":"application/octet-stream",
         "lha":"application/octet-stream",
         "lzh":"application/octet-stream",
         "exe":"application/octet-stream",
         "class":"application/octet-stream",
         "so":"application/octet-stream",
         "dll":"application/octet-stream",
         "oda":"application/oda",
         "pdf":"application/pdf",
         "ai":"application/postscript",
         "eps":"application/postscript",
         "ps":"application/postscript",
         "smi":"application/smil",
         "smil":"application/smil",
         "mif":"application/vnd.mif",
         "xls":"application/vnd.ms-excel",
         "xlsx":"application/vnd.ms-excel",
         "ppt":"application/vnd.ms-powerpoint",
         "pptx":"application/vnd.ms-powerpoint",
         "wbxml":"application/vnd.wap.wbxml",
         "wmlc":"application/vnd.wap.wmlc",
         "wmlsc":"application/vnd.wap.wmlscriptc",
         "bcpio":"application/x-bcpio",
         "vcd":"application/x-cdlink",
         "pgn":"application/x-chess-pgn",
         "cpio":"application/x-cpio",
         "csh":"application/x-csh",
         "dcr":"application/x-director",
         "dir":"application/x-director",
         "dxr":"application/x-director",
         "dvi":"application/x-dvi",
         "spl":"application/x-futuresplash",
         "gtar":"application/x-gtar",
         "hdf":"application/x-hdf",
         "js":"application/x-javascript",
         "skp":"application/x-koan",
         "skd":"application/x-koan",
         "skt":"application/x-koan",
         "skm":"application/x-koan",
         "latex	":"application/x-latex",
         "nc":"application/x-netcdf	",
         "cdf":"application/x-netcdf",
         "sh":"application/x-sh",
         "shar":"application/x-shar",
         "swf":"application/x-shockwave-flash",
         "sit":"application/x-stuffit",
         "sv4cpio":"application/x-sv4cpio",
         "sv4crc":"application/x-sv4crc",
         "tar":"application/x-tar",
         "tcl":"application/x-tcl",
         "tex":"application/x-tex",
         "texinfo":"application/x-texinfo",
         "texi":"application/x-texinfo",
         "t":"application/x-troff",
         "tr":"application/x-troff",
         "roff":"application/x-troff",
         "man":"application/x-troff-man",
         "me":"application/x-troff-me",
         "ms":"application/x-troff-ms",
         "ustar":"application/x-ustar",
         "src":"application/x-wais-source",
         "xhtml":"application/xhtml+xml",
         "xht":"application/xhtml+xml",
         "zip":"application/zip",
         "au":"audio/basic",
         "snd":"audio/basic",
         "mid":"audio/midi",
         "midi":"audio/midi",
         "kar":"audio/midi",
         "mpga":"audio/mpeg",
         "mp2":"audio/mp2",
         "mp3":"audio/mp3",
         "aif":"audio/x-aiff",
         "aiff":"audio/x-aiff",
         "aifc":"audio/x-aiff",
         "m3u":"audio/x-mpegurl",
         "ram":"audio/x-pn-realaudio",
         "rm":"audio/x-pn-realaudio",
         "rpm":"audio/x-pn-realaudio-plugin",
         "ra":"audio/x-realaudio",
         "wav":"audio/wav",
         "pdb":"chemical/x-pdb",
         "xyz":"chemical/x-xyz",
         "bmp":"image/bmp",
         "gif":"image/gif",
         "ief":"image/ief",
         "jpeg":"image/jpeg",
         "jpg":"image/jpeg",
         "jpe":"image/jpeg",
         "png":"image/png",
         "tiff":"image/tiff",
         "tif":"image/tiff",
         "djvu":"image/vnd.djvu",
         "djv":"image/vnd.djvu",
         "wbmp":"image/vnd.wap.wbmp",
         "ras":"image/x-cmu-raster",
         "pnm":"image/x-portable-anymap",
         "pbm":"image/x-portable-bitmap",
         "pgm":"image/x-portable-graymap",
         "ppm":"image/x-portable-pixmap",
         "rgb":"image/x-rgb",
         "xbm":"image/x-xbitmap",
         "xpm":"image/x-xpixmap",
         "xwd":"image/x-xwindowdump",
         "igs":"model/iges",
         "iges":"model/iges",
         "msh":"model/mesh",
         "mesh":"model/mesh",
         "silo":"model/mesh",
         "wrl":"model/vrml",
         "vrml":"model/vrml",
         "css":"text/css",
         "html":"text/html",
         "htm":"text/html",
         "asc":"text/plain",
         "txt":"text/plain",
         "rtx":"text/richtext",
         "rtf":"text/rtf",
         "sgml":"text/sgml",
         "sgm":"text/sgml",
         "tsv":"text/tab-separated-values",
         "wml":"text/vnd.wap.wml",
         "wmls":"text/vnd.wap.wmlscript",
         "etx":"text/x-setext",
         "xsl":"text/xml",
         "xml":"text/xml",
         "mpeg":"video/mpg",
         "mpg":"video/mpg",
         "mpe":"video/x-mpeg",
         "qt":"video/quicktime",
         "mov":"video/quicktime",
         "mxu":"video/vnd.mpegurl",
         "avi":"video/x-msvideo",
         "movie":"video/x-sgi-movie",
         "ice":"x-conference/x-cooltalk",
         "3gp":"video/3gpp",
         "mp4":"video/mp4",
         "rp":"image/vnd.rn-realpix",
         "qml":"application/octet-stream",
         "xmind":"application/octet-stream"
    }
}
