import QtQuick 2.2
import FmQRcode 1.0

/*!
    \qmltype AppQRcode
    \since FmQRcode 1.0
    \inqmlmodule FmQRcode
    \brief 二维码管理组件 包含二维码加码与解码二维码
*/
Item {
    id:mainItem

    /*!
    \qmlsignal tagFound
        解码结果，当成功解码之后，激发此信号
        tag 解码之后的字符串
    */
    signal tagFound(var tag)
    signal decodingFinished(var sus)
    signal decodingStarted()

    //qml 相机
    property var cammera: null

    //qml VideoOutput
    property var videoOutput: null

    //需要扫码的范围
    property alias captureRect: zxingFilter.captureRect //QRectF

    property var qrFilter:zxingFilter

    //property alias imagePath:zxingFilter.imagePath

    /*!
        \qmlmethod decodeImage
        \list
            \li function decodeImage(image,x,y,w,h)
            \li 说明：对图像进行解码，传入Qimage图像对象，指定解码区域或使用默认的全图区域进行解码，解码成功后，将激发tagFound信号，返回解码信息
         \endlist
         \sa tagFound
    */
    function decodeImage(image,x,y,w,h){
        //idFmQRcode.decodeImage(image, x||-1,y||-1,w||-1,h||-1);
    }

    function decodeImageWithPath(imagePath){
        idFmQRcode.decodeImageWithPath(imagePath);
    }

    /*!
        \qmlmethod var encodeString
        \list
            \li function encodeString(enString,callbac)
            \li 说明：传入字符串，生成二维码， 当成功生成二维码之后，调用传入的回调，返回二维码图片路径
         \endlist
         \sa tagFound
    */
    function encodeString(enString,callback){
        var obj = idQREnCodeComponent.createObject(mainItem, {"qrData": enString, "saveCallBack": callback});
        obj.encodeString();
    }

    /*!
        \qmlproperty string qrForeground
        默认值： "#29aee1"，二维码前景色
    */
    property string qrForeground: "#29aee1"

    /*!
        \qmlproperty string qrBackground
        默认值：  "white"，二维码背景色
    */
    property string qrBackground: "white"

    /*!
        \qmlproperty int qrMargin
        默认值： 2.，二维码间距
    */
    property int qrMargin: 2

    /*!
        \qmlproperty string qrLogo
        默认值：  "".，二维码中央logo
    */
    property string qrLogo: ""

    //解析本地文件
    FmQRcode{
        id:idFmQRcode
        onTagFound: {
            mainItem.tagFound(tag);
        }
        onDecodingFinished:{
            mainItem.decodingFinished(sus);
        }

    }

    QZXing{
        id:idZing
        onDecodingStarted: {
            mainItem.decodingStarted();
        }

        onDecodingFinished: {
            mainItem.decodingFinished(succeeded);
        }
        onTagFound: {
             mainItem.tagFound(tag);
        }
    }

    function decodeImageQML(item){
        idZing.decodeImageQML(item);
    }

    function decodeSubImageQML(item,x,y,w,h){
        idZing.decodeSubImageQML(item,x,y,w,h);
    }

    QZXingFilter{
        id: zxingFilter
        //captureRect: captureRect
        /*{
            // setup bindings
            if(videoOutput && captureRect){
                videoOutput.contentRect;
                videoOutput.sourceRect;
//                return videoOutput.mapRectToSource(videoOutput.mapNormalizedRectToItem(Qt.rect(
//                    0.25, 0.25, 0.5, 0.5
//                )));
                return captureRect;
            }
        }*/

//        DecoderFormat_Aztec = 1 << 1,
//        DecoderFormat_CODABAR = 1 << 2,
//        DecoderFormat_CODE_39 = 1 << 3,
//        DecoderFormat_CODE_93 = 1 << 4,
//        DecoderFormat_CODE_128 = 1 << 5,
//        DecoderFormat_DATA_MATRIX = 1 << 6,
//        DecoderFormat_EAN_8 = 1 << 7,
//        DecoderFormat_EAN_13 = 1 << 8,
//        DecoderFormat_ITF = 1 << 9,
//        DecoderFormat_MAXICODE = 1 << 10,
//        DecoderFormat_PDF_417 = 1 << 11,
//        DecoderFormat_QR_CODE = 1 << 12,
//        DecoderFormat_RSS_14 = 1 << 13,
//        DecoderFormat_RSS_EXPANDED = 1 << 14,
//        DecoderFormat_UPC_A = 1 << 15,
//        DecoderFormat_UPC_E = 1 << 16,
//        DecoderFormat_UPC_EAN_EXTENSION = 1 << 17

        decoder {
            enabledDecoders: QZXing.DecoderFormat_EAN_13 | QZXing.DecoderFormat_CODE_39 | QZXing.DecoderFormat_QR_CODE

            onTagFound: {
                console.log(tag + " | " + decoder.foundedFormat() + " | " + decoder.charSet());

//                window.detectedTags++;
//                window.lastTag = tag;
                mainItem.tagFound(tag);
            }

            tryHarder: true
        }

        onDecodingStarted: {
            //console.log("started decod");
             mainItem.decodingStarted();
        }

        //计算每秒帧数
//        property int framesDecoded: 0
//        property real timePerFrameDecode: 0

        onDecodingFinished: {
//           timePerFrameDecode = (decodeTime + framesDecoded * timePerFrameDecode) / (framesDecoded + 1);
//           framesDecoded++;
//           console.log("frame finished: " + succeeded, decodeTime, timePerFrameDecode, framesDecoded);
            console.log("frame finished: " + succeeded);
            //mainItem.decodingFinished(succeeded);
        }
    }

    Component{
        id:idQREnCodeComponent
        QREnCode{
            id:idQREnCode
            property var saveCallBack:function(path){

            }

            width: mainItem.width
            height: mainItem.width
            qrSize: Qt.size(width,width)
            anchors.centerIn: parent
            qrForeground: mainItem.qrForeground //encode color
            qrBackground: mainItem.qrBackground//"white"
            qrMargin: mainItem.qrMargin//2
            qrMode: QREnCode.MODE_8    //encode model
            qrLevel: QREnCode.LEVEL_H // encode level
            qrLogo: mainItem.qrLogo//"" //or local path or qrc path but not network url
            onQrSaveFileChanged: {
                if (idQREnCode.saveCallBack instanceof Function)
                    idQREnCode.saveCallBack(qrfilepath);
            }
        }
    }
}

