import QtQuick 2.2
import QtQml 2.2
import QtQuick.Controls 1.1

import FmTalkingData 1.0
/*!
    \qmltype AppTalkingData
    \since FmTalkingData 1.0
    \inqmlmodule FmTalkingData
    \brief 应用统计分析组件

    此组件是单例组件，可定义多个在多个地方使用，但收到的信号和内容都是一样的
    此组件应尽早初始化（一般在程序启动时初始化）

    用法示例：
    \code
    AppTalkingData{
        id:idFmTalkingData
        appId:"85E0020567FC00EB79D73962C7D9447B"
        channelId:"appStore"
    }
    \endcode

    Android使用需要在清单文件中application标签下配置类似如下代码
    \code
    <applicaiton>
    <meta-data android:name="TD_APP_ID" android:value="Your_app_id" />
    <meta-data android:name="TD_CHANNEL_ID" android:value="Your_channel_id" />
    </application>
    \endcode

*/

Item{
    id:idTalkingData
    //在talkingdata平台创建应用后获取到的appid
    property string appId : ""
    onAppIdChanged: {
        TalkingData.appId = appId;
    }

    //渠道的id，用于区分不同渠道下应用的统计信息
    property string channelId: ""
    onChannelIdChanged: {
        TalkingData.channelId = channelId;
    }

    //页面统计 进入某页面时调用
    property var trackPageBegin:function(pageName){
        TalkingData.trackPageBegin(pageName);
    }

    //页面统计  出某页面时调用
    property var trackPageEnd:function(pageName){
        TalkingData.trackPageEnd(pageName);
    }

    /*!
        \qmlmethod trackEvent
        \list
            \li function trackEvent(eventId,eventLable,jsonObj)
            \li 说明：自定义事件（包含灵动分析）
            \li 参数：
            \list
                \li eventId  string  事件id、事件名称（自定义）
                \li eventLable string 事件标签（自定义）
                \li jsonObj jsobject(json对象), 事件参数（key 和 value都需要是string类型）
            \endlist
         \endlist
         \sa
    */
    property var trackEvent:function(eventId,eventLable,jsonObj){
        TalkingData.trackEvent(eventId,eventLable,jsonObj);
    }

    property var getDeviceID:function(){
        return TalkingData.getDeviceID();
    }
}
