import QtQuick 2.2
import QtQuick.Controls 1.1
import FmWeiXin 1.0
/*!
    \qmltype AppWeiXin
    \since FmWeiXin 1.0
    \inqmlmodule FmWeiXin
    \brief 包装微信sdk

    建议此组件,在应用中只定义一次
    用法示例：
    \code
    FmWeiXin{
        appId:"33iijfoehfooefhoe"
        description:"描述信息"
        wxSence:0
    }
    \endcode
*/
Item{
    id:idFmWeiXin
//    FmWeiXin{
//        id:_weiXin
//        //发送分享信息返回后收到的信息 0:成功 －2:取消
//        onReturnError:{
//            onResp(errNum,errMsg);
//        }
//    }


    signal authDone(var jsonObj);
    signal receiveInfo(var jsonObj);

    Connections{
        target:WeiXin
        onReturnError:{
            console.log("onReturnError :",errNum,errMsg)
            onResp(errNum,errMsg);
        }
        // login done
        onAuthDone:{
            idFmWeiXin.authDone(jsonObj);
        }
        onReceiveInfo:{
            idFmWeiXin.receiveInfo(jsonObj);
        }
    }

    /*!
      \qmlproperty string appId
        从网站申请的appId
    */
    property string appId: ""
    onAppIdChanged: {
        WeiXin.appId = idFmWeiXin.appId;
    }

    /*!
      \qmlproperty string appId
        从网站申请的appId
    */
    property string appSecret: ""
    onAppSecretChanged: {
        WeiXin.appSecret = idFmWeiXin.appSecret;
    }

    /*!
      \qmlproperty string description
        描述信息
    */
    property string description: ""
    onDescriptionChanged: {
        WeiXin.description = idFmWeiXin.description;
    }

    /*!
      \qmlproperty string wxSence
        信息要发送到的场景 0:会话 1:朋友圈 2:收藏  默认为0
    */
    property int wxSence: -1
    onWxSenceChanged: {
        WeiXin.wxSence = idFmWeiXin.wxSence;
    }

    /*!
        \qmlmethod onResp
        \list
            \li function onResp(errNum,errMsg)
            \li 说明：发送一个分享内容后，收到微信的回应
            \li 参数：
            \list
                \li errNum  int 错误码
                \li errMsg string 错误描述信息
            \endlist
         \endlist
         \sa
    */
//需要在下面函数中设置，指定代理类onResp才能起作用
//- (BOOL)application:(UIApplication *)application handleOpenURL:(NSURL *)url
//    {
//        return  [WXApi handleOpenURL:url delegate:self];
//    }

    property var onResp: function(errNum,errMsg){

    }

    //每次打开应用时都需要注册 xcode 工程中url type需要设置，不然不能返回原应用
    property var registerApp: function(callback){
        return WeiXin.registerApp();
    }

    property var canOpenWeiXin: function(){
        return WeiXin.canOpenWeiXin();
    }

    property var authorizeRequest: function(info){
        return WeiXin.authorizeRequest(info);
    }

    property var sendTextContent:function(msg){
        WeiXin.sendTextContent(msg);
    }

    property var sendImageContent:function(imagePath, thumbImagePath){
        WeiXin.sendImageContent(imagePath,thumbImagePath);
    }

    property var sendLinkContent: function(title,description,url,thumbImagePath){
        WeiXin.sendLinkContent(title,description,url,thumbImagePath);
    }

    property var sendMusicContent: function(title,description,dataUrl,musiWebpageUrl,thumbImagePath){
        WeiXin.sendMusicContent(title,description,dataUrl,musiWebpageUrl,thumbImagePath);
    }

    property var sendVideoContent: function(title,description,url,thumbImagePath){
        WeiXin.sendVideoContent(title,description,url,thumbImagePath);
    }
    property var sendAppContent: function(title,description,url,thumbImagePath,extInfo){
        WeiXin.sendAppContent(title,description,url,thumbImagePath,extInfo);
    }

    property var sendNonGifContent: function(thumbImagePath,imagePath){
        WeiXin.sendNonGifContent(thumbImagePath,imagePath);
    }

    property var sendGifContent: function(thumbImagePath,gifPath){
        WeiXin.sendGifContent(thumbImagePath,gifPath);
    }

    property var sendFileContent: function(title,description,filePath,thumbImagePath){
        WeiXin.sendFileContent(title,description,filePath,thumbImagePath);
    }

    property var getUserInfo: function(){
        return WeiXin.getUserInfo();
    }

    property var reNewToken: function(token){
        WeiXin.reNewToken(token);
    }
}
